==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/entity/SwHcXm.java <==
package cn.gtmap.landtax.entity;/**
 * Created by janeshen on 2014/8/19.
 */

import com.alibaba.fastjson.annotation.JSONField;
import org.hibernate.annotations.*;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.*;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.util.Date;
import java.util.Set;

/**
 * .
 * <p/>
 * 税务核查项目（包括了税源核查、宗地核查、疑点清册核查）
 * @author shenjian
 * @version V1.0, 2014/8/19
 */
@Entity
@org.hibernate.annotations.Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@Table(name = "SW_HC_XM")
public class SwHcXm {
    @Id
    @Column(name = "ID")
    private String xmId;
    @Column
    private String mc;
    @Column
    private String cjrId;
    @Column
    private String xmlx;
    @Column
    private Date cjrq;
    @Column
    private String xmybj;


    @OneToMany(mappedBy = "swHcXm",fetch = FetchType.LAZY)
    Set<SwHcXmRwRel> swHcXmRwRelSet;


    public String getXmId() {
        return xmId;
    }

    public void setXmId(String xmId) {
        this.xmId = xmId;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getCjrId() {
        return cjrId;
    }

    public void setCjrId(String cjrId) {
        this.cjrId = cjrId;
    }

    public String getXmlx() {
        return xmlx;
    }

    public void setXmlx(String xmlx) {
        this.xmlx = xmlx;
    }

    public Date getCjrq() {
        return cjrq;
    }

    public void setCjrq(Date cjrq) {
        this.cjrq = cjrq;
    }

    @JSONField(serialize = false)
    public Set<SwHcXmRwRel> getSwHcXmRwRelSet() {
        return swHcXmRwRelSet;
    }

    public void setSwHcXmRwRelSet(Set<SwHcXmRwRel> swHcXmRwRelSet) {
        this.swHcXmRwRelSet = swHcXmRwRelSet;
    }

    public String getXmybj() {
        return xmybj;
    }

    public void setXmybj(String xmybj) {
        this.xmybj = xmybj;
    }
}

==> landtax-1.0.0-20160602.090753-7-sources.jar: cn/gtmap/landtax/entity/SwHcXm.java <==
package cn.gtmap.landtax.entity;/**
 * Created by janeshen on 2014/8/19.
 */

import com.alibaba.fastjson.annotation.JSONField;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import javax.persistence.*;
import java.util.Date;
import java.util.Set;

/**
 * .
 * <p/>
 * 税务核查项目（包括了税源核查、宗地核查、疑点清册核查）
 * @author shenjian
 * @version V1.0, 2014/8/19
 */
@Entity
@org.hibernate.annotations.Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@Table(name = "SW_HC_XM")
public class SwHcXm {
    @Id
    @Column(name = "ID")
    private String xmId;
    @Column
    private String mc;
    @Column
    private String cjrId;
    @Column
    private String xmlx;
    @Column
    private Date cjrq;
    @Column
    private String xmybj;


    @OneToMany(mappedBy = "swHcXm",fetch = FetchType.LAZY)
    Set<SwHcXmRwRel> swHcXmRwRelSet;


    public String getXmId() {
        return xmId;
    }

    public void setXmId(String xmId) {
        this.xmId = xmId;
    }

    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }

    public String getCjrId() {
        return cjrId;
    }

    public void setCjrId(String cjrId) {
        this.cjrId = cjrId;
    }

    public String getXmlx() {
        return xmlx;
    }

    public void setXmlx(String xmlx) {
        this.xmlx = xmlx;
    }

    public Date getCjrq() {
        return cjrq;
    }

    public void setCjrq(Date cjrq) {
        this.cjrq = cjrq;
    }

    @JSONField(serialize = false)
    public Set<SwHcXmRwRel> getSwHcXmRwRelSet() {
        return swHcXmRwRelSet;
    }

    public void setSwHcXmRwRelSet(Set<SwHcXmRwRel> swHcXmRwRelSet) {
        this.swHcXmRwRelSet = swHcXmRwRelSet;
    }

    public String getXmybj() {
        return xmybj;
    }

    public void setXmybj(String xmybj) {
        this.xmybj = xmybj;
    }
}
